﻿Event.observe(window, 'load', function ()
{
  window.availableCores = window.availableCores || null;
  window.dialogId = window.dialogId || null;
  window.selectedInstanceCount = window.selectedInstanceCount || null;
  window.selectedVmSize = window.selectedVmSize || null;
  window.vmSizesJson = window.vmSizesJson || null;
  window.Control = window.Control || null;
  window.$R = window.$R || null;

  if (!parent || !parent.Sitecore || !parent.Sitecore.Azure || !parent.Sitecore.Azure.Manager || !parent.Sitecore.Azure.Manager.translate)
  {
    return;
  }

  // Displaying errors/warnings of the 'Number of instances' slider.

  $("instancesWarning").title = parent.Sitecore.Azure.Manager.translate("DeploymentHasOneRoleWithOnlyOneInstance");
  $("instancesError").title = parent.Sitecore.Azure.Manager.translate("DeploymentCannotHasZeroInstance");

  // Parsing the VM size data source JSON.

  try
  {
    window.vmSizes = vmSizesJson.evalJSON();
  }
  catch (error)
  {
    closeDialog();

    return;
  }

  // Closing the dialog if no available cores.

  if (!availableCores)
  {
    closeDialog();

    return;
  }

  // TODO: check if the following IF statement is relevant.

  if (!Object.isArray(vmSizes))
  {
    window.vmSizes = [vmSizes];
  }

  // Loading the VM Size combo box.

  loadVmSizeComboBox();

  // Binding the Instance Number slider.

  bindInstanceNumberSlider(getVmSizeIndex());
});

function bindInstanceNumberSlider(vmSizeIndex)
{
  var vmSize = vmSizes[vmSizeIndex];
  var maxInstanceCount = Math.floor(availableCores / vmSize.cores);
  var instanceCount = selectedInstanceCount;

  if (!instanceCount)
  {
    instanceCount = 2;
  }

  instanceCount = parseInt(instanceCount, '10') > maxInstanceCount ? maxInstanceCount : parseInt(instanceCount, '10');

  var instanceCounts = getValues(1, maxInstanceCount + 1);

  if (this.slider)
  {
    this.slider.dispose();
  }

  this.slider = new Control.Slider(
    'instancesNumber_handle',
    'instancesNumber_track',
    {
      maximum: maxInstanceCount,

      range: ((maxInstanceCount - 1) > 0) ? $R(1, maxInstanceCount) : $R(0, 1),

      value: instanceCount,

      values: instanceCounts,

      onChange: function (v)
      {
        $('instancesNumber_DisplayName').innerHTML = v;
        $('instancesNumber_Value').value = v;

        if (v == 0)
        {
          $('instancesError').show();
          $('OK').disable();
        }
        else
        {
          $('instancesError').hide();
          $('OK').enable();
        }

        if (v == 1)
        {
          $('instancesWarning').show();
        }
        else
        {
          $('instancesWarning').hide();
        }
      },

      onSlide: function (v)
      {
        $('instancesNumber_DisplayName').innerHTML = v;
      },
    });

  slider.setValue(instanceCount);
}

function closeDialog()
{
  if (parent.azureManager)
  {
    parent.azureManager.closeModelessDialog(dialogId);
  }
}

function getValues(min, max)
{
  if (max <= min)
  {
    return [0];
  }

  var values = new Array(max - min);

  for (var i = min; i < max; i++)
  {
    values[i - min] = i;
  }

  return values;
}

function getVmSizeIndex()
{
  var count = vmSizes.length;

  for (var i = 0; i < count; i++)
  {
    if (vmSizes[i].value == selectedVmSize)
    {
      return i;
    }
  }

  return 0;
}

function loadVmSizeComboBox()
{
  // Getting the VM Size combo box.

  var comboBox = $("VmSizeComboBox");

  // Getting a count of VM sizes.

  var count = vmSizes.length;

  // Populating the VM Size combo box.

  for (var i = 0; i < count; i++)
  {
    var item = vmSizes[i];
    var option = document.createElement("option");
    option.value = item.value;
    option.innerHTML = item.displayName;
    comboBox.appendChild(option);
  }

  // Selecting the VM size.

  var index = getVmSizeIndex();
  comboBox.selectedIndex = index;
  $('vmSize_Value').value = vmSizes[index].value;

  // Subscribing to 'onchange' event.

  comboBox.onchange = onVmSizeComboBoxChange;
}

function onVmSizeComboBoxChange()
{
  var comboBox = $("VmSizeComboBox");
  var index = comboBox.selectedIndex;
  $('vmSize_Value').value = vmSizes[index].value;
  bindInstanceNumberSlider(index);
}